@@ -5,7 +5,7 @@ use warnings;
 package Kavorka::Sub::Around;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010';
+our $VERSION   = '0.011';
 
 use Moo;
 with 'Kavorka::MethodModifier';
@@ -15,7 +15,7 @@ sub default_invocant
 	my $self = shift;
 	return (
 		'Kavorka::Signature::Parameter'->new(
-			name      => '${^NEXT}',
+			name      => '$next',
 			traits    => { invocant => 1 },
 		),
 		'Kavorka::Signature::Parameter'->new(
@@ -27,4 +27,14 @@ sub default_invocant
 
 sub method_modifier { 'around' }
 
+around inject_prelude => sub
+{
+	my $next = shift;
+	my $self = shift;
+	return join '' => (
+		'*{^NEXT} = \\$_[0];',
+		$self->$next(@_),
+	);
+};
+
 1;
